@@ -30,6 +30,7 @@ def _args_debug(args_parser):  # pragma: no cover
         )
     )
 
+    # deprecated
     args.add_argument(
         '--show-current-chapter-info',
         action='store_true',
@@ -38,6 +39,7 @@ def _args_debug(args_parser):  # pragma: no cover
         )
     )
 
+    # deprecated
     args.add_argument(
         '--save-current-chapter-info',
         action='store_true',
@@ -46,6 +48,30 @@ def _args_debug(args_parser):  # pragma: no cover
         )
     )
 
+    args.add_argument(
+        '--show-chapter-info',
+        action='store_true',
+        help=(
+            'Show current processing chapter info.'
+        )
+    )
+
+    args.add_argument(
+        '--save-chapter-info',
+        action='store_true',
+        help=(
+            'Save current processing chapter info into a JSON file.'
+        )
+    )
+
+    args.add_argument(
+        '--save-manga-info',
+        action='store_true',
+        help=(
+            'Saves the manga data in a into a JSON file at the root of the download folder.'
+        )
+    )
+
     args.add_argument(
         '--debug',
         action='store_true',
@@ -62,4 +88,3 @@ def _args_debug(args_parser):  # pragma: no cover
             'Dont show any messages.'
         )
     )
-
