@@ -536,6 +536,8 @@ providers_list = {
         r'komikstation\.com/.+-chapter-.',
         r'mangavy\.com/manga/.',
         r'mangavy\.com/.+-chapter-.',
+        r'asurascans\.com/comics/.',
+        r'asurascans\.com/.+-chapter-.',
     ],
     'submanga_online': [
         r'submanga\.online/manga/.',
@@ -599,7 +601,8 @@ providers_list = {
     'zeroscans_com': [
         r'zeroscans\.com/comics/.',
         r'reaperscans\.com/comics/.',
-        r'secretscans\.co/comics/.',
+        r'secretscan\.co/comics/.',
+        r'lynxscans\.com/comics/.',
         r'kkjscans\.co/comics/.',
         r'kkjscans\.co/comics/.',
         r'edelgardescans\.com/comics/.',
