@@ -10,7 +10,7 @@ class AsmHentaiCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return '0'
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
