@@ -8,7 +8,7 @@ class ComicPunchNet(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'[-/]((?:Annual|Issue|Chapter)-\w+)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
