@@ -33,9 +33,5 @@ class DesuMe(Provider, Std):
     def get_cover(self):
         return self._cover_from_content('.c-poster > img')
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
-
 
 main = DesuMe
