@@ -27,7 +27,7 @@ class MangaFoxMe(Provider, Std):
             return '{}-{}'.format(idx, groups[0])
         return idx
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
