@@ -5,9 +5,14 @@ from .helpers.std import Std
 class HeavenMangaBiz(Provider, Std):
 
     def get_chapter_index(self) -> str:
-        return self.re.search(r'-chap-(\d+(?:-\d+)?)', self.chapter).group(1)
+        try:
+            return self.re.search(r'-chap-(\d+(?:-\d+)?)', self.chapter).group(1)
+        except Exception as e:
+            if self.re.search(r'-chap$', self.chapter):
+                return '0'
+            raise e
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
