@@ -13,7 +13,7 @@ class HocVienTruyenTranhCom(Provider, Std):
             url = self.html_fromstring(url, '#subNavi a', 0).get('href')
         return url
 
-    def get_main_content(self):
+    def get_content(self):
         url = self._test_main_url(self.get_url())
         return self.http_get(self.http().normalize_uri(url))
 
