@@ -14,7 +14,7 @@ class HoduComicsCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'view/(\d+)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         content = self._storage.get('main_content', None)
         if content is None:
             self._storage['main_content'] = self.http_get(self.get_url())
