@@ -7,7 +7,7 @@ class LeviatanScansCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'.+/(\d+/\d+)', self.chapter).group(1).replace('/', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
