@@ -10,7 +10,7 @@ class MangAs(Provider, Std):
         idx = self.re.search('/manga/[^/]+/([^/]+)', self.chapter).group(1)
         return idx.replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
