@@ -5,7 +5,7 @@ from .mangaonline_today import MangaOnlineToday
 class MangaDeepCom(MangaOnlineToday, Std):
 
     def get_chapter_index(self) -> str:
-        idx = self.re.search(r'\.com/[^/]+/([^/]+)', self.chapter)
+        idx = self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', self.chapter)
         return idx.group(1)
 
     def document_fromstring(self, body, selector: str = None, idx: int = None):
@@ -14,7 +14,7 @@ class MangaDeepCom(MangaOnlineToday, Std):
         return super().document_fromstring(body, selector, idx)
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.com/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         selector = 'ul.lst a.lst'
