@@ -7,10 +7,6 @@ from .helpers.std import Std
 class NightowNet(Provider, Std):
     _name_re = r'manga=(.+?)(?:&.+)?$'
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index()
-        return self.normal_arc_name(idx.split('-'))
-
     def get_chapter_index(self) -> str:
         ch = unquote_plus(self.chapter)
         idx = self.re.search(r'chapter=(?:.+?)\+(\d+(?:\.\d+)?)', ch)
@@ -18,7 +14,7 @@ class NightowNet(Provider, Std):
             return '-'.join(idx.group(1).split('.'))
         return self.re.search('chapter=(.+?)(?:&.+)?$', ch).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         name = self._get_name(self._name_re)
         return self.http_get('{}/online/?manga={}'.format(
             self.domain,
