@@ -6,8 +6,8 @@ class NozomiNoFansubCom(KomikIdCom):
 
     def get_chapter_index(self) -> str:
         re = self.re.compile(r'/manga/[^/]+/.+?(\d+(?:[^\d/]\d+)?)')
-        ch = self.chapter
-        return re.search(ch).group(1)
+        split = self.re.compile(r'[^\d+]')
+        return '-'.join(split.split(re.search(self.chapter).group(1)))
 
 
 main = NozomiNoFansubCom
