@@ -10,7 +10,7 @@ class RawDevArtComOld(Provider, Std):
         idx = self.re.search(self._chapter_selector, self.chapter)
         return '-'.join(idx.group(1).split('.'))
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
