@@ -11,7 +11,7 @@ class ReaderIMangaScansOrg(Provider, Std):
         re = self.re.search(r'://.+?/[^/]+/([^/]+)', self.chapter)
         return re.group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
