@@ -13,7 +13,7 @@ class ShogakukanCoJp(ShogakukanTameshiyoMe, Std):
     def get_chapter_index(self) -> str:
         return str(self.chapter_id)
 
-    def get_main_content(self):
+    def get_content(self):
         types = [
             'magazines/series',
             'books'
