@@ -11,7 +11,7 @@ class SoMangaNet(Provider, Std):
         re = self.re.compile('/leitor/[^/]+/([^/]+)')
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
