@@ -9,7 +9,7 @@ class WMangaRu(Provider, Std):
         idx = self.re.search(selector, self.chapter).groups()
         return '{}-{}'.format(*idx)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/starter/manga_byid/{}')
 
     def get_manga_name(self) -> str:
